﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.IO;
using MP3TagLib;

namespace GetTag
{
    public class GetTagMP3
    {
        public GetTagMP3() { }

        public Dictionary<TagName, string> GetTag(string fName)
        {
            Dictionary<TagName, string> retDic = new Dictionary<TagName, string>();
            string loName = fName.ToLower();
            if (File.Exists(loName) == false)
                return retDic;
            //
            if (loName.EndsWith(".mp3") == false)
                return retDic;

            List<MP3Frame> tagData = new List<MP3Frame>();
            MP3Tag tag = new MP3Tag();
            tagData = tag.Read(fName);
            if (tagData == null) //MP3だが、タグがない
                return SetFrame(fName, tagData);

            //普通のタグ処理
            return SetFrame(fName, tagData);
        }

        private Dictionary<TagName, string> SetFrame(string fName, List<MP3Frame> tagData)
        {
            //普通のタグ処理
            Dictionary<TagName, string> retDic = new Dictionary<TagName, string>();
            retDic.Add(TagName.path, fName);
            retDic.Add(TagName.fileName, Path.GetFileName(fName));
            DateTime dt = File.GetCreationTime(fName); //作成日時の取得
            retDic.Add(TagName.createTime, dt.ToString());

            SortedDictionary<TagName, string> sortDic //XML で整列のため
                = new SortedDictionary<TagName, string>();
            if (tagData != null)
            {
                GetFrameNormal(tagData, sortDic);
            }
            //値のないフレームに空白
            //string[] frName = new string[] { "album","artist","comment","composer","genre"
            //    ,"lyric","pic","title","track","year"};
            string[] frName = Enum.GetNames(typeof(TagName));
            for (int i = 0; i < frName.Length; i++)
            {
                TagName tgn = (TagName)Enum.Parse(typeof(TagName), frName[i]);
                if (tgn == TagName.path || tgn == TagName.fileName || tgn == TagName.createTime)
                    continue;
                if (!sortDic.ContainsKey(tgn))
                    sortDic.Add(tgn,"");
                //if (!sortDic.ContainsKey((TagName)Enum.Parse(typeof(TagName),frName[i])))
                //    sortDic.Add((TagName)Enum.Parse(typeof(TagName),frName[i]), "");

                //if (!sortDic.ContainsKey(frName[i]))
                //    sortDic.Add(frName[i], "");
            }
            //ソートしたままretDicに追加
            foreach (KeyValuePair<TagName, string> kvp in sortDic)
            {
                retDic.Add(kvp.Key, kvp.Value);
            }
            return retDic;
        }

        private void GetFrameNormal(List<MP3Frame> tagData
                    , SortedDictionary<TagName, string> sortDic)
        {
            foreach (MP3Frame frame in tagData)
            {
                TagName frameName = GetFrameName(frame);
                //if (frameName == null)
                //    continue;
                string frameVal = "";

                switch (frameName)
                {
                    case TagName.pic:
                        frameVal = "*P*";
                        break;
                    case TagName.comment:
                        frameVal = "*C*";
                        break;
                    case TagName.lyric:
                        frameVal = "*L*";
                        break;
                    default:
                        frameVal = (string)frame.dataObj;
                        break;
                }
                if (frameVal == "")
                    continue;
                if (!sortDic.ContainsKey(frameName))
                    sortDic.Add(frameName, frameVal);
            }
        }

        private TagName GetFrameName(MP3Frame frame)
        {
            TagName retName = TagName.title;
            switch (frame.frameID)
            {
                case FrameID.APIC:
                    retName = TagName.pic;
                    break;
                case FrameID.COMM:
                    retName = TagName.comment;
                    break;
                case FrameID.TALB:
                    retName = TagName.album;
                    break;
                case FrameID.TCOM:
                    retName = TagName.composer;
                    break;
                case FrameID.TCON:
                    retName = TagName.genre;
                    break;
                case FrameID.TENC:
                    break;
                case FrameID.TIT2:
                    retName = TagName.title;
                    break;
                case FrameID.TPE1:
                    retName = TagName.artist;
                    break;
                case FrameID.TPOS:
                    break;
                case FrameID.TRCK:
                    retName = TagName.track;
                    break;
                case FrameID.TSSE:
                    break;
                case FrameID.TYER:
                    retName = TagName.year;
                    break;
                case FrameID.UFID:
                    break;
                case FrameID.USLT:
                    retName = TagName.lyric;
                    break;
                case FrameID.XNOP:
                    break;
                default:
                    break;
            }
            return retName;
        }
    }
}
