﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using NUnit.Framework;

namespace GetTag.Test
{
    [TestFixture]
    public class GetMP3TagTest
    {
        private Dictionary<TagName, string> resDic
                = new Dictionary<TagName, string>();
        private string mp3Path = @"F:\Test\";

        [Test]
        public void TestNormal()
        {
            GetTagMP3 getTest = new GetTagMP3();
            mp3Path += "01.mp3";
            resDic = getTest.GetTag(mp3Path);
            Assert.AreEqual(14, resDic.Count);
            string val = "";
            val = resDic[TagName.title];
            Assert.AreEqual("さすらい", val);
        }
        [Test]
        public void TestNonMP3()
        {
            GetTagMP3 getTest = new GetTagMP3();
            mp3Path += "noTag.mp3";
            resDic = getTest.GetTag(mp3Path);

            Assert.AreEqual(14, resDic.Count);
        }
        [Test]
        public void Test存在しない()
        {
            GetTagMP3 getTest = new GetTagMP3();
            mp3Path += "xyz.mp3";
            resDic = getTest.GetTag(mp3Path);

            Assert.AreEqual(0, resDic.Count);
        }
        [Test]
        public void Testタグなし()
        {
            GetTagMP3 getTest = new GetTagMP3();
            mp3Path += "noTag.mp3";
            resDic = getTest.GetTag(mp3Path);

            Assert.AreEqual(14, resDic.Count);
        }
        [Test]
        public void PICありTest()
        {
            GetTagMP3 getTest = new GetTagMP3();
            mp3Path += "01.mp3";
            resDic = getTest.GetTag(mp3Path);
            if (resDic.ContainsKey(TagName.pic))
            {
                Assert.AreEqual("*P*", resDic[TagName.pic]);
            }
            else
            {
                Assert.False(true, "picがない");
            }
            Assert.AreEqual(14, resDic.Count);
        }
        [Test]
        public void ComeありTest()
        {
            GetTagMP3 getTest = new GetTagMP3();
            mp3Path += "01.mp3";
            resDic = getTest.GetTag(mp3Path);
            Assert.AreEqual(14, resDic.Count);

            if (resDic.ContainsKey(TagName.comment))
            {
                Assert.AreEqual("*C*", resDic[TagName.comment]);
            }
            else
            {
                Assert.False(true, "ommentがない");
            }
        }
        [Test]
        public void LyricありTest()
        {
            GetTagMP3 getTest = new GetTagMP3();
            mp3Path += "01.mp3";
            resDic = getTest.GetTag(mp3Path);
            Assert.AreEqual(14, resDic.Count);

            if (resDic.ContainsKey(TagName.lyric))
            {
                Assert.AreEqual("*L*", resDic[TagName.lyric]);
            }
            else
            {
                Assert.False(true, "lyricがない");
            }
        }
    }
}
